@@ -2,7 +2,7 @@ package Amon2::DBI;
 use strict;
 use warnings;
 use 5.008001;
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use parent qw/DBI/;
 
@@ -50,10 +50,7 @@ sub connect_info { $_[0]->{private_connect_info} }
 
 sub _txn_manager {
     my $self = shift;
-    if (!defined $self->{private_txn_manager}) {
-        $self->{private_txn_manager} = DBIx::TransactionManager->new($self);
-    }
-    return $self->{private_txn_manager};
+    return DBIx::TransactionManager->new($self);
 }
 
 sub txn_scope { $_[0]->_txn_manager->txn_scope(caller => [caller(0)]) }
